==> mobx-angular-1.5.0.jar: META-INF/resources/webjars/mobx-angular/1.5.0/CHANGELOG.md <==
<a name="1.5.0"></a>
# 1.5.0 (2017-04-19)
* Added @action to proxy decorator

<a name="1.4.2"></a>
# 1.4.2 (2017-04-12)
* Updated bug with angular 4 debug name

<a name="1.4.1"></a>
# 1.4.1 (2017-04-04)
* Updated dependencies to support Angular 4

<a name="1.3.0"></a>
# 1.3.0 (2017-03-07)
* Renamed to mobx-angular

<a name="1.2.9"></a>
# 1.2.9 (2017-02-25)
* Added computed wrapper

<a name="1.2.8"></a>
# 1.2.8 (2017-02-22)
* Solved @computed twice issue
* Deprecate mobxAutorunSync

<a name="1.2.7"></a>
# 1.2.7 (2017-02-22)
* Fixed using pipe - createEmbeddedView inside ngOnInit

<a name="1.2.6"></a>
# 1.2.6 (2017-02-09)
* Fixed exports / declarations in module

<a name="1.2.5"></a>
# 1.2.5 (2017-02-06)
* Added observable proxy for test

<a name="1.2.4"></a>
# 1.2.4 (2017-02-04)
* Replaced main / jsnext:main / module mismatch

<a name="1.2.3"></a>
# 1.2.3 (2017-02-04)
* Added AoT metadata
* Added UMD bundle
* Checking for localStorage / console in debug

<a name="1.2.2"></a>
# 1.2.2 (2017-01-21)
* Fixed change detection errors by creating element in constructor, and auto detecting in afterViewInit
* Fixed ng2MobxDebug element positioning

<a name="1.2.1"></a>
# 1.2.1 (2017-01-21)
* Added ng2MobxDebug

<a name="1.2.0"></a>
# 1.2.0 (2017-01-21)
* Update example to be like TodoMVC
* Update target compilation to ES5
* Fixed dependencies
* Added AoT
* mobxReaction fires immediately

<a name="1.1.3"></a>
# 1.1.3 (2016-11-12)
* Using autorunAsync instead of sync

<a name="1.1.2"></a>
# 1.1.2 (2016-11-10)
* Relaxed Angular peer dependency requirement
* Fix typo in readme

<a name="1.1.1"></a>
# 1.1.1 (2016-10-27)
* Added mobxReaction directive

<a name="1.1.0"></a>
# 1.1.0 (2016-10-27)
* Changed approach to use mobxAutorun directive

<a name="1.0.1"></a>
# 1.0.1 (2016-10-24)
* Initial version

==> mobx-angular-1.9.0.jar: META-INF/resources/webjars/mobx-angular/1.9.0/CHANGELOG.md <==
<a name="1.9.0"></a>
# 1.9.0 (2017-10-05)
* Changed MobXDebug element to right-click

<a name="1.8.1"></a>
# 1.8.1 (2017-10-05)
* Fixed MobxDebug on browsers where localStorage === null

<a name="1.8.0"></a>
# 1.8.0 (2017-10-03)
* Fixed MobxDebug on browsers where localStorage === null

<a name="1.7.0"></a>
# 1.7.0 (2017-09-03)
* Fixed MobX dependency

<a name="1.6.0"></a>
# 1.6.0 (2017-08-17)
* Upgraded to MobX 3.0.0

<a name="1.5.0"></a>
# 1.5.0 (2017-04-19)
* Added @action to proxy decorator

<a name="1.4.2"></a>
# 1.4.2 (2017-04-12)
* Updated bug with angular 4 debug name

<a name="1.4.1"></a>
# 1.4.1 (2017-04-04)
* Updated dependencies to support Angular 4

<a name="1.3.0"></a>
# 1.3.0 (2017-03-07)
* Renamed to mobx-angular

<a name="1.2.9"></a>
# 1.2.9 (2017-02-25)
* Added computed wrapper

<a name="1.2.8"></a>
# 1.2.8 (2017-02-22)
* Solved @computed twice issue
* Deprecate mobxAutorunSync

<a name="1.2.7"></a>
# 1.2.7 (2017-02-22)
* Fixed using pipe - createEmbeddedView inside ngOnInit

<a name="1.2.6"></a>
# 1.2.6 (2017-02-09)
* Fixed exports / declarations in module

<a name="1.2.5"></a>
# 1.2.5 (2017-02-06)
* Added observable proxy for test

<a name="1.2.4"></a>
# 1.2.4 (2017-02-04)
* Replaced main / jsnext:main / module mismatch

<a name="1.2.3"></a>
# 1.2.3 (2017-02-04)
* Added AoT metadata
* Added UMD bundle
* Checking for localStorage / console in debug

<a name="1.2.2"></a>
# 1.2.2 (2017-01-21)
* Fixed change detection errors by creating element in constructor, and auto detecting in afterViewInit
* Fixed ng2MobxDebug element positioning

<a name="1.2.1"></a>
# 1.2.1 (2017-01-21)
* Added ng2MobxDebug

<a name="1.2.0"></a>
# 1.2.0 (2017-01-21)
* Update example to be like TodoMVC
* Update target compilation to ES5
* Fixed dependencies
* Added AoT
* mobxReaction fires immediately

<a name="1.1.3"></a>
# 1.1.3 (2016-11-12)
* Using autorunAsync instead of sync

<a name="1.1.2"></a>
# 1.1.2 (2016-11-10)
* Relaxed Angular peer dependency requirement
* Fix typo in readme

<a name="1.1.1"></a>
# 1.1.1 (2016-10-27)
* Added mobxReaction directive

<a name="1.1.0"></a>
# 1.1.0 (2016-10-27)
* Changed approach to use mobxAutorun directive

<a name="1.0.1"></a>
# 1.0.1 (2016-10-24)
* Initial version
